<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://your-style.nl/
 * @since      1.0.0
 *
 * @package    Ysp_Business
 * @subpackage Ysp_Business/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Ysp_Business
 * @subpackage Ysp_Business/includes
 * @author     Yourstyle <info@your-style.nl>
 */
class Ysp_Business {

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Ysp_Business_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct() {
		if ( defined( 'YSP_BUSINESS_VERSION' ) ) {
			$this->version = YSP_BUSINESS_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'ysp-business';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_admin_hooks();
		$this->define_public_hooks();

	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Ysp_Business_Loader. Orchestrates the hooks of the plugin.
	 * - Ysp_Business_i18n. Defines internationalization functionality.
	 * - Ysp_Business_Admin. Defines all hooks for the admin area.
	 * - Ysp_Business_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies() {

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once YSP_BUSINESS_DIR . 'includes/loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once YSP_BUSINESS_DIR . 'includes/i18n.php';

		/**
		 * The class responsible for checking for updates of the plugin.
		 */
		require_once YSP_BUSINESS_DIR . 'includes/update-checker.php';

		/**
		 * The class responsible for the templates of the plugin.
		 */
		require_once YSP_BUSINESS_DIR . 'includes/templates.php';

		/**
		 * The class responsible for defining all actions that occur in the admin area.
		 */
		require_once YSP_BUSINESS_DIR . 'admin/admin.php';

        /* Classes */
        require_once YSP_BUSINESS_DIR . 'admin/classes/class-employee-columns.php';
        require_once YSP_BUSINESS_DIR . 'admin/classes/class-office-columns.php';

        /* Meta Fields */
        require_once YSP_BUSINESS_DIR . 'admin/meta-fields/meta-employee-office.php';
        require_once YSP_BUSINESS_DIR . 'admin/meta-fields/meta-employee.php';
        require_once YSP_BUSINESS_DIR . 'admin/meta-fields/meta-office-employees.php';
        require_once YSP_BUSINESS_DIR . 'admin/meta-fields/meta-office.php';

        /* Post types */
        require_once YSP_BUSINESS_DIR . 'admin/post-types/cpt-employee.php';
        require_once YSP_BUSINESS_DIR . 'admin/post-types/cpt-office.php';

        /* Taxonomies */
        require_once YSP_BUSINESS_DIR . 'admin/taxonomies/tax-employee-category.php';
        require_once YSP_BUSINESS_DIR . 'admin/taxonomies/tax-office-location.php';
        require_once YSP_BUSINESS_DIR . 'admin/taxonomies/tax-office-types.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once YSP_BUSINESS_DIR . 'public/public.php';
        
        /* Plugin Helpers */
		require_once YSP_BUSINESS_DIR . 'includes/plugin-helpers.php';

        /* Components - Shortcodes */
        require_once YSP_BUSINESS_DIR . 'public/partials/components/shortcodes/templates/class-employee-template.php';
        require_once YSP_BUSINESS_DIR . 'public/partials/components/shortcodes/templates/class-office-template.php';
        require_once YSP_BUSINESS_DIR . 'public/partials/components/shortcodes/class-employee-list.php';
        require_once YSP_BUSINESS_DIR . 'public/partials/components/shortcodes/class-employee-single.php';
        require_once YSP_BUSINESS_DIR . 'public/partials/components/shortcodes/class-employee-slider.php';
        require_once YSP_BUSINESS_DIR . 'public/partials/components/shortcodes/class-office-list.php';
        require_once YSP_BUSINESS_DIR . 'public/partials/components/shortcodes/class-office-single.php';
        require_once YSP_BUSINESS_DIR . 'public/partials/components/shortcodes/class-office-slider.php';

        /* Components - Visual Composer */
        require_once YSP_BUSINESS_DIR . 'public/partials/components/visual-composer/employee-list-to-vc.php';
        require_once YSP_BUSINESS_DIR . 'public/partials/components/visual-composer/employee-single-to-vc.php';
        require_once YSP_BUSINESS_DIR . 'public/partials/components/visual-composer/employee-slider-to-vc.php';
        require_once YSP_BUSINESS_DIR . 'public/partials/components/visual-composer/office-list-to-vc.php';
        require_once YSP_BUSINESS_DIR . 'public/partials/components/visual-composer/office-single-to-vc.php';
        require_once YSP_BUSINESS_DIR . 'public/partials/components/visual-composer/office-slider-to-vc.php';
        
        /* Shortcodes */
        require_once YSP_BUSINESS_DIR . 'public/partials/shortcodes/employee-shortcodes.php';
        require_once YSP_BUSINESS_DIR . 'public/partials/shortcodes/office-shortcodes.php';


		$this->loader = new Ysp_Business_Loader();

	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Ysp_Business_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale() {

		$plugin_i18n = new Ysp_Business_i18n();

		$this->loader->add_action( 'plugins_loaded', $plugin_i18n, 'load_plugin_textdomain' );

	}

	/**
	 * Register all of the hooks related to the admin area functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_admin_hooks() {

		$plugin_admin = new Ysp_Business_Admin( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_styles' );
		$this->loader->add_action( 'admin_enqueue_scripts', $plugin_admin, 'enqueue_scripts' );
		$this->loader->add_action( 'init', $plugin_admin, 'setup_rewrites' );

	}

	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks() {

		$plugin_public = new Ysp_Business_Public( $this->get_plugin_name(), $this->get_version() );

		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_styles' );
		$this->loader->add_action( 'wp_enqueue_scripts', $plugin_public, 'enqueue_scripts' );

	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run() {
		$updateChecker = new Ysp_Business_UpdateChecker();
		$updateChecker->start();
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name() {
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Ysp_Business_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader() {
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version() {
		return $this->version;
	}

}